@@ -4,6 +4,7 @@ from explainaboard.loaders import (
     get_custom_dataset_loader,
     get_datalab_loader,
 )
+from explainaboard.meta_analyses import RankFlippingMetaAnalysis, RankingMetaAnalysis
 from explainaboard.processors import get_processor
 from explainaboard.tasks import get_task_categories, Task, TaskCategory
 
@@ -18,4 +19,6 @@ __all__ = [
     'Task',
     'TaskCategory',
     'TaskType',
+    'RankFlippingMetaAnalysis',
+    'RankingMetaAnalysis',
 ]
