@@ -12,6 +12,8 @@ from explainaboard.loaders import (
     loader_registry,
     qa_multiple_choice,
     sequence_labeling,
+    tabular_classification,
+    tabular_regression,
     text_classification,
     text_pair_classification,
 )
@@ -30,6 +32,8 @@ __all__ = [
     'loader',
     'sequence_labeling',
     'qa_multiple_choice',
+    'tabular_classification',
+    'tabular_regression',
     'text_classification',
     'text_pair_classification',
     'cloze_generative',
