@@ -22,7 +22,7 @@ from explainaboard.info import (
     Result,
     SysOutputInfo,
 )
-from explainaboard.metric import Metric, MetricConfig, MetricStats
+from explainaboard.metrics.metric import Metric, MetricConfig, MetricStats
 import explainaboard.utils.bucketing
 from explainaboard.utils.cache_api import (
     read_statistics_from_cache,
@@ -169,6 +169,7 @@ class Processor(metaclass=abc.ABCMeta):
         true_data = [self._get_true_label(x) for x in sys_output]
         pred_data = [self._get_predicted_label(x) for x in sys_output]
         metric_stats = []
+
         for metric in metrics:
             metric_stats.append(metric.calc_stats_from_data(true_data, pred_data))
         return metric_stats
@@ -547,7 +548,8 @@ class Processor(metaclass=abc.ABCMeta):
         sys_info.features = self._customize_features(custom_features)
 
         # get scoring statistics
-        metric_stats = unwrap(self._gen_metric_stats(sys_info, sys_output))
+        metric_stats = self._gen_metric_stats(sys_info, sys_output)
+        metric_stats = unwrap(metric_stats)
         external_stats = self._gen_external_stats(sys_info, self._statistics_func)
         active_features = self._complete_features(
             sys_info, sys_output, external_stats=external_stats
