@@ -104,6 +104,46 @@ class BaseLoaderTests(TestCase):
 
 
 class TestLoadFromDatalab(TestCase):
+    def test_datalab_loader(self):
+        output_data = '\n'.join(['positive' for x in range(872)])
+        loader = get_datalab_loader(
+            task=TaskType.text_classification,
+            dataset=DatalabLoaderOption("sst2", split="validation"),
+            output_data=output_data,
+            output_source=Source.in_memory,
+            output_file_type=FileType.text,
+        )
+        data = loader.load()
+        self.assertEqual(len(data.samples), 872)
+
+    def test_datalab_loader_with_features(self):
+        output_data = '\n'.join(['x' for _ in range(500)])
+        # Without features
+        loader = get_datalab_loader(
+            task=TaskType.machine_translation,
+            dataset=DatalabLoaderOption("conala", split="test"),
+            output_data=output_data,
+            output_source=Source.in_memory,
+            output_file_type=FileType.text,
+        )
+        data = loader.load()
+        self.assertEqual(len(data.samples), 500)
+        self.assertFalse('orig_en' in data.samples[0])
+        # With features
+        custom_features = ['orig_en']
+        loader = get_datalab_loader(
+            task=TaskType.machine_translation,
+            dataset=DatalabLoaderOption(
+                "conala", split="test", custom_features=custom_features
+            ),
+            output_data=output_data,
+            output_source=Source.in_memory,
+            output_file_type=FileType.text,
+        )
+        data = loader.load()
+        self.assertEqual(len(data.samples), 500)
+        self.assertTrue('orig_en' in data.samples[0])
+
     def test_invalid_dataset_name(self):
         loader = get_datalab_loader(
             task=TaskType.text_classification,
